@@ -31,8 +31,10 @@ from easydev import execute, TempFile, Progress, md5, DevTools
 
 from sequana import sequana_config_path
 from sequana.lazy import pandas as pd
-from sequana import logger
-logger.name = __name__
+import colorlog
+logger = colorlog.getLogger(__name__)
+
+
 
 
 __all__ = ["KrakenBuilder"]
