@@ -23,8 +23,9 @@ from sequana.lazy import numpy as np
 import platform
 import pathlib
 
-from sequana import logger
-logger.name = __name__
+import colorlog
+logger = colorlog.getLogger(__name__)
+
 
 
 from docutils import core
