@@ -4,15 +4,20 @@ import sys
 import os
 import glob
 import click
+#import click_completion
+
+#click_completion.init()
+
 from sequana import version
 import functools
 
 __all__ = ["main"]
 
 import sequana
-from sequana import logger
 
-logger.level = "INFO"
+import colorlog
+logger = colorlog.getLogger(__name__)
+
 
 # This can be used by all commands as a simple decorator
 def common_logger(func):
@@ -155,84 +160,15 @@ def samplesheet(**kwargs):
 @click.argument("name", type=click.Path(exists=True), nargs=-1)
 @click.option("--module",
     required=False,
-    type=click.Choice(["rnadiff", "bamqc", "bam", "enrichment", "fasta",
-        "fastq", "gff"]))
-@click.option("--enrichment-taxon", type=click.INT,
-    #required=True,
-    default=0,
-    help="a valid taxon identifiers")
-@click.option("--enrichment-kegg-name", type=click.STRING,
-    default=None,
-    help="a valid KEGG name (automatically filled for 9606 (human) and 10090 (mmusculus)")
-@click.option("--enrichment-log2-foldchange-cutoff", type=click.FLOAT,
-    default=1,
-    show_default=True,
-    help="remove events with absolute log2 fold change below this value")
-@click.option("--enrichment-padj-cutoff", type=click.FLOAT,
-    default=0.05,
-    show_default=True,
-    help="remove events with pvalue abobe this value default (0.05).")
-@click.option("--enrichment-biomart", type=click.STRING,
-    default=None,
-    help="""you may need a biomart mapping of your identifier for the kegg
-pathways analysis. If you do not have this file, you can use 'sequana biomart'
-command""")
-@click.option("--enrichment-go-only", type=click.BOOL,
-    default=False,
-    is_flag=True,
-    help="""to run only panther db enrichment""")
-@click.option("--enrichment-plot-linearx", type=click.BOOL,
-    default=False,
-    is_flag=True,
-    help="""Default is log2 fold enrichment in the plots. use this to use linear scale""")
-@click.option("--enrichment-compute-levels", type=click.BOOL,
-    default=False,
-    is_flag=True,
-    help="""to compute the GO levels (slow) in the plots""")
-@click.option("--enrichment-max-genes", type=click.INT,
-    default=3000,
-    help="""Maximum number of genes (up or down) to use in PantherDB, which is limited to about 3000""")
-@click.option("--enrichment-kegg-only", type=click.BOOL,
-    default=False,
-    is_flag=True,
-    help="""to run only kegg patways enrichment""")
-@click.option("--enrichment-kegg-pathways-directory", type=click.Path(),
-    default=None,
-    help="""a place where to find the pathways for each organism""")
-@click.option("--enrichment-kegg-background", type=click.INT,
-    default=None,
-    help="""a background for kegg enrichment. If None, set to number of genes found in KEGG""")
-@click.option("--rnadiff-annotation", type=click.Path(),
-    default=None,
-    help="""The GFF file used to perform the annotation""")
-@common_logger
+    type=click.Choice(["bamqc", "bam", "fasta", "fastq", "gff"]))
 def summary(**kwargs):
-    """Create a HTML report for various sequana out
+    """Create a HTML report for various type of NGS formats.
 
     \b
-    * rnadiff: the output of RNADiff pipeline
-    * enrichment: the output of RNADiff pipeline
     * bamqc
     * fastq
 
-    Example for the enrichment module:
-
-        sequana summary T1vsT0.complete.xls --module enrichment --enrichment-taxon 10090 
-        --enrichment-log2-foldchange-cutoff 2 --enrichment-kegg-only
-
-    The KEGG pathways are loaded and it may take time. Once done, they are saved
-    in kegg_pathways/organism and be loaded next time:
-
-        sequana summary T1vsT0.complete.xls --module enrichment --enrichment-taxon 10090 
-            --enrichment-log2-foldchange-cutoff 2 --enrichment-kegg-only
-            --enrichment-kegg-pathways-directory kegg_pathways
-
-    For the RNADIFF module::
-
-        sequana summary --module rnadiff \
-            --rnadiff-annotation final_annotation.gff `ls ./tables/B4239-v2.*.complete.xls`
-
-    This will process all files in the given pattern (in back quots)
+    This will process all files in the given pattern (in back quotes)
     sequentially and procude one HTML file per input file.
 
 
@@ -264,59 +200,6 @@ def summary(**kwargs):
             print(f"Processing {name}")
             from sequana.modules_report.bamqc import BAMQCModule
             report = BAMQCModule(name, "bamqc.html")
-    elif module == "rnadiff":
-        for name in names:
-            from sequana.rnadiff import RNADiffResults
-            from sequana.modules_report.rnadiff import RNAdiffModule
-            if name.split(".")[-1] == 'xls':
-                output_filename = name.replace(".xls", ".html")
-            else:
-                output_filename = name + ".html"
-            output_filename = output_filename.split("/")[-1]
-
-            if kwargs['rnadiff_annotation']:
-                logger.info(f"Processing annoation file into annotations.csv")
-                from sequana import GFF3
-                GFF3(kwargs['rnadiff_annotation']).save_annotation_to_csv()
-            logger.info(f"Processing {name} into {output_filename}")
-            data = RNADiffResults(name)
-            report = RNAdiffModule(data, output_filename)
-    elif module == "enrichment":
-        try:
-            name = names[0]
-        except:
-            logger.error()
-            sys.exit(1)
-        from sequana.modules_report.enrichment import Enrichment
-        taxon = kwargs['enrichment_taxon']
-        if taxon == 0:
-            logger.error("You must provide a taxon with --enrichment_taxon")
-            return
-        keggname = kwargs['enrichment_kegg_name']
-        params = {"padj": kwargs['enrichment_padj_cutoff'],
-                  "log2_fc": kwargs['enrichment_log2_foldchange_cutoff'],
-                  "max_entries": kwargs['enrichment_max_genes'],
-                  "mapper": kwargs['enrichment_biomart'],
-                  "kegg_background": kwargs['enrichment_kegg_background'],
-                  "preload_directory": kwargs['enrichment_kegg_pathways_directory'],
-                  "plot_logx": not kwargs['enrichment_plot_linearx'],
-                  "plot_compute_levels": kwargs['enrichment_compute_levels'],
-                }
-        filename = kwargs['enrichment_biomart']
-        if filename and os.path.exists(filename) is False:
-            logger.error("{} does not exists".format(filename))
-            sys.exit(1)
-        filename = kwargs['enrichment_kegg_pathways_directory']
-        if filename and os.path.exists(filename) is False:
-            logger.error("{} does not exists".format(filename))
-            sys.exit(1)
-
-        report = Enrichment(name, taxon,
-            kegg_organism=keggname, 
-            enrichment_params=params,
-            go_only=kwargs["enrichment_go_only"],
-            kegg_only=kwargs["enrichment_kegg_only"], 
-            command=" ".join(['sequana'] + sys.argv[1:]))
     elif module == "fasta": # there is no module per se. HEre we just call FastA.summary()
         from sequana.fasta import FastA
         for name in names:
@@ -349,6 +232,133 @@ def summary(**kwargs):
             ff.get_duplicated_attributes_per_type()
 
 
+@main.command()
+@click.option("--annotation", type=click.Path(),
+    default=None,
+    help="""The GFF file used to perform the annotation""")
+@click.option("--report-only", 
+    is_flag=True,
+    default=False,
+    help="""generate report only assuming results are already present""")
+@click.option("--output-directory", type=click.Path(),
+    default="rnadiff",
+    help="""Output directory where are saved the results""")
+@click.option("--features", type=click.Path(),
+    default="all_features.out",
+    help="""The Counts from feature counts. This should be the output of the
+            sequana_rnaseq pipeline all_features.out """)
+@click.option("--design", type=click.Path(),
+    default="design.csv", help="""It should have been generated by sequana_rnaseq. If
+not, it must be a comma separated file with two columns. One for the label to be
+found in the --features file and one column with the condition to which it
+belong. E.g. with 3 replicates and 2 conditions. It should look like:
+
+\b
+label,condition
+WT1,WT
+WT2,WT
+WT3,WT
+file1,cond1
+fileother,cond1
+""")
+@click.option("--feature-name",
+    default="gene",
+    help="""The feature name compatible with your GFF. """)
+@click.option("--attribute-name",
+    default="ID",
+    help="""The attribute used as identifier. compatible with your GFF. """)
+@click.option("--reference", type=click.Path(),
+    default=None,
+    help="""The reference to test DGE against. If provided, conditions not
+            involving the reference are ignored.""")
+@click.option("--comparisons", type=click.Path(),
+    default=None,
+    help="""Not yet implemented. By default, all comparisons are computed""")
+@common_logger
+def rnadiff(**kwargs):
+    """Create HTML report for the differential analysis of sequana_rnaseq output.
+
+
+        sequana rnadiff --annotation Lepto.gff  \
+            --design design.csv --features all_features.out \
+             --feature-name gene --attribute-name ID 
+
+
+
+    """
+    from sequana.featurecounts import FeatureCount
+    from sequana.rnadiff import RNADiffAnalysis, RNADesign
+    from sequana.modules_report.rnadiff import RNAdiffModule
+
+    logger.setLevel(kwargs['logger'])
+
+    outdir = kwargs['output_directory']
+    feature = kwargs['feature_name']
+    attribute = kwargs['attribute_name']
+    design = kwargs['design']
+    reference=kwargs['reference']
+
+    if kwargs['annotation']:
+        gff = kwargs['annotation']
+        logger.info(f"Checking annotation file")
+        from sequana import GFF3
+        g = GFF3(gff) #.save_annotation_to_csv()
+        if feature not in  g.get_types():
+            logger.critical(f"{feature} not found in the GFF. Most probably a wrong feature name")
+        attributes = g.get_attributes(feature)
+        if attribute not in attributes:
+            logger.critical(f"{attribute} not found in the GFF for the provided feature. Most probably a wrong feature name. Please change --attribute-name option or do not provide any GFF")
+            sys.exit(1)
+    else:
+        gff = None
+
+    design_check = RNADesign(design, reference=reference)
+    comparisons = kwargs['comparisons']
+    if comparisons is None:
+        comparisons = design_check.comparisons
+
+    if kwargs['report_only'] is False:
+        logger.info(f"Processing features counts and saving into light_counts.csv")
+        fc = FeatureCount(kwargs['features'])
+        fc.rnadiff_df.to_csv("light_counts.csv")
+
+        logger.info(f"Differential analysis. Saving into ./{outdir}")
+        r = RNADiffAnalysis("light_counts.csv", design,
+                condition="condition",
+                comparisons=comparisons,
+                fc_feature=feature,
+                fc_attribute=attribute,
+                outdir=outdir,
+                gff=gff)
+
+        logger.info(f"Saving output files into {outdir}/rnadiff.csv")
+        try:
+            results = r.run()
+            results.to_csv(f"{outdir}/rnadiff.csv")
+        except Exception as err:
+            logger.error(err)
+            sys.exit(1)
+        else:
+            logger.info(f"DGE done.")
+            # cleanup if succesful
+            os.remove("rnadiff.err")
+            os.remove("rnadiff.out")
+            os.remove("rnadiff_light.R")
+
+
+    logger.info(f"Reporting. Saving in rnadiff.html")
+    report = RNAdiffModule(outdir, kwargs['design'], gff=gff,
+                fc_attribute=attribute,
+                fc_feature=feature,
+                alpha=0.05,
+                log2_fc=0,
+                group="condition",
+                annot_cols=None,
+                pattern="*vs*_degs_DESeq2.csv")
+
+
+
+
 
 @main.command()
 @click.option("--mart", default="ENSEMBL_MART_ENSEMBL",
@@ -375,7 +385,7 @@ def biomart(**kwargs):
 
     """
     print(kwargs)
-    logger.level = kwargs["logger"]
+    logger.setLevel(kwargs["logger"])
 
     mart = kwargs['mart']
     attributes = kwargs['attributes']
@@ -422,3 +432,207 @@ def gtf_fixer(**kwargs):
 
 
 
+# This will be a complex command to provide HTML summary page for
+# input files (e.g. bam), or results from pipelines. For each module,
+# we should have corresponding option that starts with the module's name
+# This can also takes as input various types of data (e.g. FastA)
+@main.command()
+@click.argument("name", type=click.Path(exists=True), 
+    nargs=1)
+@click.option("--annotation-attribute", type=click.STRING,
+    #required=True,
+    default="Name",
+    help="a valid taxon identifiers")
+@click.option("--panther-taxon", type=click.INT,
+    #required=True,
+    default=0,
+    help="a valid taxon identifiers")
+@click.option("--kegg-name", type=click.STRING,
+    default=None,
+    help="a valid KEGG name (automatically filled for 9606 (human) and 10090 (mmusculus)")
+@click.option("--log2-foldchange-cutoff", type=click.FLOAT,
+    default=1,
+    show_default=True,
+    help="remove events with absolute log2 fold change below this value")
+@click.option("--padj-cutoff", type=click.FLOAT,
+    default=0.05,
+    show_default=True,
+    help="remove events with pvalue abobe this value default (0.05).")
+@click.option("--biomart", type=click.STRING,
+    default=None,
+    help="""you may need a biomart mapping of your identifier for the kegg
+pathways analysis. If you do not have this file, you can use 'sequana biomart'
+command""")
+@click.option("--go-only", type=click.BOOL,
+    default=False,
+    is_flag=True,
+    help="""to run only panther db enrichment""")
+@click.option("--plot-linearx", type=click.BOOL,
+    default=False,
+    is_flag=True,
+    help="""Default is log2 fold enrichment in the plots. use this to use linear scale""")
+@click.option("--compute-levels", type=click.BOOL,
+    default=False,
+    is_flag=True,
+    help="""to compute the GO levels (slow) in the plots""")
+@click.option("--max-genes", type=click.INT,
+    default=2000,
+    help="""Maximum number of genes (up or down) to use in PantherDB, which is limited to about 3000""")
+@click.option("--kegg-only", type=click.BOOL,
+    default=False,
+    is_flag=True,
+    help="""to run only kegg patways enrichment""")
+@click.option("--kegg-pathways-directory", type=click.Path(),
+    default=None,
+    help="""a place where to find the pathways for each organism""")
+@click.option("--kegg-background", type=click.INT,
+    default=None,
+    help="""a background for kegg enrichment. If None, set to number of genes found in KEGG""")
+@common_logger
+def enrichment(**kwargs):
+    """Create a HTML report for various sequana out
+
+    \b
+    * enrichment: the output of RNADiff pipeline
+
+    Example for the enrichment module:
+
+        sequana enrichment rnadiff.csv --panther-taxon 10090 
+            --log2-foldchange-cutoff 2 --kegg-only
+
+    The KEGG pathways are loaded and it may take time. Once done, they are saved
+    in kegg_pathways/organism and be loaded next time:
+
+        sequana enrichment rnadiff/rnadiff.csv 
+            --panther-taxon 189518 \
+            --log2-foldchange-cutoff 2 --kegg-only \
+            --kegg-name lbi\
+            --annotation file.gff 
+
+    """
+    import pandas as pd
+    from sequana.modules_report.enrichment import Enrichment
+    logger.setLevel(kwargs['logger'])
+
+    taxon = kwargs['panther_taxon']
+    if taxon == 0:
+        logger.error("You must provide a taxon with --panther-taxon")
+        return
+    keggname = kwargs['kegg_name']
+    params = {"padj": kwargs['padj_cutoff'],
+              "log2_fc": kwargs['log2_foldchange_cutoff'],
+              "max_entries": kwargs['max_genes'],
+              "mapper": kwargs['biomart'],
+              "kegg_background": kwargs['kegg_background'],
+              "preload_directory": kwargs['kegg_pathways_directory'],
+              "plot_logx": not kwargs['plot_linearx'],
+              "plot_compute_levels": kwargs['compute_levels'],
+            }
+    filename = kwargs['biomart']
+    if filename and os.path.exists(filename) is False:
+        logger.error("{} does not exists".format(filename))
+        sys.exit(1)
+    filename = kwargs['kegg_pathways_directory']
+    if filename and os.path.exists(filename) is False:
+        logger.error("{} does not exists".format(filename))
+        sys.exit(1)
+
+    rnadiff_file = kwargs['name']
+    logger.info(f"Reading {rnadiff_file}")
+    rnadiff = pd.read_csv(rnadiff_file, index_col=0, header=[0,1])
+
+    # now that we have loaded all results from a rnadiff analysis, let us
+    # perform the enrichment for each comparison found in the file
+    annot_col = kwargs['annotation_attribute']
+    Nmax = kwargs['max_genes']
+
+    from sequana.utils import config
+
+    for compa in rnadiff.columns.levels[0]:
+        if compa not in ['statistics', 'annotation']:
+            # get gene list
+            df = rnadiff[compa].copy()
+
+            # we add the annotation
+            for x in rnadiff['annotation'].columns:
+                df[x] = rnadiff['annotation'][x]
+
+            # now we find the gene lists
+            padj = params['padj']
+            log2fc = params['log2_fc']
+            df = df.query("(log2FoldChange >=@log2fc or log2FoldChange<=-@log2fc) and padj <= @padj")
+            df.reset_index(inplace=True)
+
+            dfup = df.sort_values("log2FoldChange", ascending=False)
+            up_genes = list(dfup.query("log2FoldChange > 0")[annot_col])[:Nmax]
+
+            dfdown = df.sort_values("log2FoldChange", ascending=True)
+            down_genes = list(dfdown.query("log2FoldChange < 0")[annot_col])[:Nmax]
+
+            all_genes = list(
+                df.sort_values("log2FoldChange", key=abs,ascending=False)[annot_col]
+            )[:Nmax]
+
+            gene_dict = {
+                 "up": up_genes,
+                 "down": down_genes,
+                 "all": all_genes,
+             }
+
+            Nup = len(up_genes)
+            Ndown = len(down_genes)
+            N = Nup + Ndown
+            logger.info(f"Computing enrichment for the {compa} case")
+            logger.info(f"Found {Nup} genes up-regulated, {Ndown} down regulated ({N} in total).")
+            config.output_dir = f"enrichment/{compa}"
+            report = Enrichment(gene_dict, taxon, df,
+                kegg_organism=keggname, 
+                enrichment_params=params,
+                go_only=kwargs["go_only"],
+                kegg_only=kwargs["kegg_only"], 
+                command=" ".join(['sequana'] + sys.argv[1:]))
+
+
+
+@main.command()
+@click.option("--search-kegg", type=click.Path(),
+    default=None,
+    help="""Search a pattern amongst all KEGG organism""")
+@click.option("--search-panther", type=click.Path(),
+    default=None,
+    help="""Search a pattern amongst all KEGG organism""")
+@common_logger
+def taxonomy(**kwargs):
+    """Tool to retrieve taxonomic information.
+
+    sequana taxonomy --search-kegg leptospira
+    """
+
+    if kwargs['search_kegg']:
+        from sequana.kegg import KEGGHelper
+        k = KEGGHelper()
+        results = k.search(kwargs['search_kegg'].lower())
+        print(results)
+    elif kwargs['search_panther']:
+        import pandas as pd
+        from sequana import sequana_data
+        df = pd.read_csv(sequana_data("panther.csv"), index_col=0)
+
+        pattern = kwargs['search_panther']
+        f1 = df[[True if pattern in x else False for x in df['name']]]
+        f2 = df[[True if pattern in x else False for x in df.short_name]]
+        f3 = df[[True if pattern in x else False for x in df.long_name]]
+        indices = list(f1.index) + list(f2.index) + list(f3.index)
+ 
+        if len(indices) == 0:
+            # maybe it is a taxon ID ?
+            f4 = df[[True if pattern in str(x) else False for x in df.taxon_id]]
+            indices = list(f4.index)
+        indices = set(indices)
+        print(df.loc[indices])
+ 
+
+
+
+
+
