@@ -53,11 +53,11 @@ from ruamel.yaml import comments
 
 from sequana.misc import wget
 from sequana import version as sequana_version
-from sequana import sequana_data, logger
 from sequana.errors import SequanaException
 
+import colorlog
+logger = colorlog.getLogger(__name__)
 
-logger.name = __name__
 
 
 __all__ = ["DOTParser", "FastQFactory", "FileFactory",
@@ -564,9 +564,9 @@ or open a Python shell and type::
             except:
                 # is this a Python code ?
                 if len(easydev.get_dependencies(req)) == 0:
-                    logger.error("%s not found !! " % req + 
+                    logger.error("%s requirement not found !! " % req + 
                         "Let us move on but you must probably install " + 
-                        "it to benefit from all fonctionalities")
+                        "it to benefit from all fonctionalities.")
                     executable = False
                     missing.append(req)
                 else:
@@ -642,8 +642,6 @@ class SequanaConfig(object):
         >>> sc.config.pattern == "*.fastq.gz"
         True
 
-
-
     Empty strings in a config are interpreted as None but SequanaConfig will
     replace  None with empty strings, which is probably what was expected from
     the user. Similarly, in snakemake when settings the config file, one
@@ -799,6 +797,7 @@ class SequanaConfig(object):
         If not, it can be either an http resources or a sequana resources.
 
         """
+    
         if 'requirements' in self._yaml_code.keys():
             for requirement in self._yaml_code['requirements']:
                 if os.path.exists(requirement):
@@ -937,7 +936,8 @@ class PipelineManagerBase(object):
             namespace['toclean'] = []
 
         try:
-            # check requirements if possible
+            # check requirements if possible. This is the standalone application
+            # requirements, not the files possibly provided in the config file
             Module(self.name).check(mode)
         except:
             pass
@@ -1143,7 +1143,11 @@ class PipelineManager(PipelineManagerGeneric):
         self.config.sequana_version = sequana_version
 
     def _get_paired(self):
-        return self.ff.paired
+        try:
+            return self.ff.paired
+        except:
+            logger.warning("cannot figure out wheter paired or not")
+            return False
     paired = property(_get_paired)
 
     def _get_fastq_files(self, glob_dir, read_tag):
