@@ -1,3 +1,22 @@
+# -*- coding: utf-8 -*-
+#
+#  This file is part of Sequana software
+#
+#  Copyright (c) 2016 - Sequana Development Team
+#
+#  File author(s):
+#      Thomas Cokelaer <thomas.cokelaer@pasteur.fr>
+#      Dimitri Desvillechabrol <dimitri.desvillechabrol@pasteur.fr>, 
+#          <d.desvillechabrol@gmail.com>
+#
+#  Distributed under the terms of the 3-clause BSD license.
+#  The full license is in the LICENSE file, distributed with this software.
+#
+#  website: https://github.com/sequana/sequana
+#  documentation: http://sequana.readthedocs.io
+#
+##############################################################################
+
 """.. rubric:: Corrplot utilities
 
 :references: http://cran.r-project.org/web/packages/corrplot/vignettes/corrplot-intro.html
@@ -13,7 +32,10 @@ from colormap import cmap_builder
 
 
 from sequana.viz.linkage import Linkage
-from sequana import logger
+
+import colorlog
+logger = colorlog.getLogger(__name__)
+
 
 from sequana.lazy import pandas as pd
 from sequana.lazy import numpy as np
